@@ -10,6 +10,7 @@
 #include <QString>
 #include <QMultimedia>
 #include <QCoreApplication>
+#include <QQuickItem>
 
 #include <audiorecorder.h>
 
@@ -44,16 +45,21 @@ public:
 
     int simpleAudioFormat() const;
     void setSimpleAudioFormat(int audioFormat);
-    
+
     QString audioCodec() const;
     void setAudioCodec(const QString &audioCodec);
-    
+
+    QString audioInput() const;
+    void setAudioInput(const QString &audioInput);
+
     QString containerFormat() const;
     void setContainerFormat(const QString &audioContainerFormat);
-    
+
     int audioQuality() const;
     void setAudioQuality(int audioQuality);
 
+    Q_INVOKABLE void setBlur(QQuickItem *item, bool blur);
+
 private:
     explicit SettingsModel(QObject *parent = nullptr);
     ~SettingsModel();
